@@ -581,7 +581,7 @@ fileutils_copy(const char *srcpath, const char *dstpath)
         return -4;
     }
 
-#ifdef HAVE_ST_BLKSIZE
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
     blksize = db.st_blksize;
 #else
 #ifdef DEV_BSIZE
@@ -816,9 +816,7 @@ er_fileutils_file_is_fits(const char *name)
     int is_fits = 0;
     int i, j, n;
 
-    int mysscanf();
-
-
+    
     if (!(fp = fopen(name, "r"))) {
         cpl_msg_error(er_func, "Unable to open FITS file '%s'", name);
         return (-2);
