@@ -29,7 +29,7 @@
 #ifdef HAVE_GETOPT_LONG_ONLY
 #include <getopt.h>
 #else
-#include "getopt.h"
+#include "er_getopt.h"
 #endif
 
 #include "ltdl.h"
