@@ -420,6 +420,9 @@ static cx_map_iterator current_module = NULL;
    this is the inverse lookup of module_list. */
 static cx_map *module_lut = NULL;
 
+/* The python interpreter command to launch */
+static const char *python_interpreter = "python";
+
 /* The following command is passed to the -c option to the Python interpreter.
    It bootstraps the more complex script in the JSON input from standard input.
    This keeps the command line length reasonably short. */
@@ -578,7 +581,8 @@ start_python_interpreter(const char *python_command,
 
         /* execlp() will either not return, or we know we have an error so stop
            the process. */
-        (void)execlp("python", "python", "-c", python_command, (char *)0);
+        (void)execlp(python_interpreter, python_interpreter, "-c",
+                     python_command, (char *)0);
         cpl_msg_debug(cpl_func, "Failed to execute python command: %s",
                       strerror(errno));
         exit(EXIT_FAILURE);
