@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Recipe Execution Tool
- * Copyright (C) 2017 European Southern Observatory
+ * Copyright (C) 2017-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,31 +56,29 @@
 cpl_boolean pipe_must_produce_error = CPL_FALSE;
 int pipe_error_countdown = 0;
 
-int _overloaded_pipe(int fildes[2])
+int
+_overloaded_pipe(int fildes[2])
 {
     --pipe_error_countdown;
-    if (pipe_must_produce_error && pipe_error_countdown < 0)
-    {
+    if (pipe_must_produce_error && pipe_error_countdown < 0) {
         errno = EIO;
         return -1;
     }
-    else
-    {
+    else {
         return pipe(fildes);
     }
 }
 
 cpl_boolean fork_must_produce_error = CPL_FALSE;
 
-pid_t _overloaded_fork(void)
+pid_t
+_overloaded_fork(void)
 {
-    if (fork_must_produce_error)
-    {
+    if (fork_must_produce_error) {
         errno = EIO;
         return -1;
     }
-    else
-    {
+    else {
         return fork();
     }
 }
@@ -88,16 +86,15 @@ pid_t _overloaded_fork(void)
 cpl_boolean dup_must_produce_error = CPL_FALSE;
 int dup_error_countdown = 0;
 
-int _overloaded_dup(int oldfd)
+int
+_overloaded_dup(int oldfd)
 {
     --dup_error_countdown;
-    if (dup_must_produce_error && dup_error_countdown < 0)
-    {
+    if (dup_must_produce_error && dup_error_countdown < 0) {
         errno = EIO;
         return -1;
     }
-    else
-    {
+    else {
         return dup(oldfd);
     }
 }
@@ -105,16 +102,15 @@ int _overloaded_dup(int oldfd)
 cpl_boolean dup2_must_produce_error = CPL_FALSE;
 int dup2_error_countdown = 0;
 
-int _overloaded_dup2(int oldfd, int newfd)
+int
+_overloaded_dup2(int oldfd, int newfd)
 {
     --dup2_error_countdown;
-    if (dup2_must_produce_error && dup2_error_countdown < 0)
-    {
+    if (dup2_must_produce_error && dup2_error_countdown < 0) {
         errno = EIO;
         return -1;
     }
-    else
-    {
+    else {
         return dup2(oldfd, newfd);
     }
 }
@@ -124,20 +120,18 @@ int close_failure_code = EIO;
 int close_error_countdown = 0;
 int close_on_which_pid = -1;
 
-int _overloaded_close(int fd)
+int
+_overloaded_close(int fd)
 {
-    if (getpid() != close_on_which_pid)
-    {
+    if (getpid() != close_on_which_pid) {
         return close(fd);
     }
     --close_error_countdown;
-    if (close_must_produce_error && close_error_countdown < 0)
-    {
+    if (close_must_produce_error && close_error_countdown < 0) {
         errno = close_failure_code;
         return -1;
     }
-    else
-    {
+    else {
         return close(fd);
     }
 }
@@ -147,22 +141,19 @@ int read_failure_code = EIO;
 int read_call_countdown = 0;
 int read_nbyte_limit = -1;
 
-ssize_t _overloaded_read(int fildes, void *buf, size_t nbyte)
+ssize_t
+_overloaded_read(int fildes, void *buf, size_t nbyte)
 {
     --read_call_countdown;
-    if (read_must_produce_error || read_call_countdown >= 0)
-    {
+    if (read_must_produce_error || read_call_countdown >= 0) {
         errno = read_failure_code;
         return -1;
     }
-    else
-    {
-        if (read_nbyte_limit > 0)
-        {
+    else {
+        if (read_nbyte_limit > 0) {
             return read(fildes, buf, read_nbyte_limit);
         }
-        else
-        {
+        else {
             return read(fildes, buf, nbyte);
         }
     }
@@ -173,22 +164,19 @@ int write_failure_code = EIO;
 int write_call_countdown = 0;
 int write_nbyte_limit = -1;
 
-ssize_t _overloaded_write(int fildes, const void * buf, size_t nbyte)
+ssize_t
+_overloaded_write(int fildes, const void *buf, size_t nbyte)
 {
     --write_call_countdown;
-    if (write_must_produce_error || write_call_countdown >= 0)
-    {
+    if (write_must_produce_error || write_call_countdown >= 0) {
         errno = write_failure_code;
         return -1;
     }
-    else
-    {
-        if (write_nbyte_limit > 0)
-        {
+    else {
+        if (write_nbyte_limit > 0) {
             return write(fildes, buf, write_nbyte_limit);
         }
-        else
-        {
+        else {
             return write(fildes, buf, nbyte);
         }
     }
@@ -196,28 +184,26 @@ ssize_t _overloaded_write(int fildes, const void * buf, size_t nbyte)
 
 cpl_boolean malloc_must_produce_error = CPL_FALSE;
 
-void * _overloaded_malloc(size_t size)
+void *
+_overloaded_malloc(size_t size)
 {
-    if (malloc_must_produce_error)
-    {
+    if (malloc_must_produce_error) {
         return NULL;
     }
-    else
-    {
+    else {
         return malloc(size);
     }
 }
 
 cpl_boolean realloc_must_produce_error = CPL_FALSE;
 
-void * _overloaded_realloc(void *ptr, size_t size)
+void *
+_overloaded_realloc(void *ptr, size_t size)
 {
-    if (realloc_must_produce_error)
-    {
+    if (realloc_must_produce_error) {
         return NULL;
     }
-    else
-    {
+    else {
         return realloc(ptr, size);
     }
 }
@@ -226,29 +212,28 @@ void * _overloaded_realloc(void *ptr, size_t size)
    waitpid is called by a certain number of invocations. */
 int waitpid_call_countdown = 0;
 
-pid_t _overloaded_waitpid(pid_t pid, int * wstatus, int options)
+pid_t
+_overloaded_waitpid(pid_t pid, int *wstatus, int options)
 {
     --waitpid_call_countdown;
-    if (waitpid_call_countdown >= 0)
-    {
+    if (waitpid_call_countdown >= 0) {
         errno = EINTR;
         return -1;
     }
-    else
-    {
+    else {
         return waitpid(pid, wstatus, options);
     }
 }
 
 /* Replace calls in the code we want to test with our overloaded functions. */
-#define pipe _overloaded_pipe
-#define fork _overloaded_fork
-#define dup _overloaded_dup
-#define dup2 _overloaded_dup2
-#define close _overloaded_close
-#define read _overloaded_read
-#define write _overloaded_write
-#define malloc _overloaded_malloc
+#define pipe    _overloaded_pipe
+#define fork    _overloaded_fork
+#define dup     _overloaded_dup
+#define dup2    _overloaded_dup2
+#define close   _overloaded_close
+#define read    _overloaded_read
+#define write   _overloaded_write
+#define malloc  _overloaded_malloc
 #define realloc _overloaded_realloc
 #define waitpid _overloaded_waitpid
 #include "er_python.c"
@@ -267,7 +252,7 @@ pid_t _overloaded_waitpid(pid_t pid, int * wstatus, int options)
                         Private function prototypes
  -----------------------------------------------------------------------------*/
 
-static void mock_python(const char * script);
+static void mock_python(const char *script);
 static void test_start_python_interpreter(void);
 static void test_run_python_command(void);
 static void test_stop_python_interpreter(void);
@@ -277,13 +262,14 @@ static void test_pipe_read_write(void);
                                   Main
  -----------------------------------------------------------------------------*/
 
-int main(void)
+int
+main(void)
 {
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
     /* Update the PATH environment variable to make sure we pick up our mock
        python script. */
-    const char * path = "./mock_python_error3_test:/usr/bin:/bin";
+    const char *path = "./mock_python_error3_test:/usr/bin:/bin";
     cpl_test_assert(setenv("PATH", path, 0x1) == 0);
 
     /* Need to restrict overloading close() to this process. */
@@ -308,7 +294,8 @@ int main(void)
  * interpreter process. The input is the shell script to write to the python
  * script file.
  */
-static void mock_python(const char * script)
+static void
+mock_python(const char *script)
 {
     /* Do not overwrite the python script if a previous test failed. This will
        make it easier to debug by having the failing script available. */
@@ -316,25 +303,24 @@ static void mock_python(const char * script)
 
     /* Create the directory for the python script. We put this in its own
        directory so that this unit test can be made concurrency safe. */
-    if (mkdir("./mock_python_error3_test", 0777) != 0)
-    {
+    if (mkdir("./mock_python_error3_test", 0777) != 0) {
         cpl_test_assert(errno == EEXIST);
     }
 
-    FILE* file = fopen("./mock_python_error3_test/python", "w");
+    FILE *file = fopen("./mock_python_error3_test/python", "w");
     cpl_test_assert(file != NULL);
     size_t bytes_to_write = strlen(script);
     size_t bytes_written = fwrite(script, sizeof(char), bytes_to_write, file);
     cpl_test_assert(bytes_written == bytes_to_write);
     int fclose_result = fclose(file);
     cpl_test_assert(fclose_result == 0);
-    mode_t mode = S_IRUSR | S_IWUSR | S_IXUSR |
-                  S_IRGRP | S_IXGRP |
-                  S_IROTH | S_IXOTH;
+    mode_t mode =
+        S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
     cpl_test_assert(chmod("./mock_python_error3_test/python", mode) == 0);
 }
 
-static void test_start_python_interpreter(void)
+static void
+test_start_python_interpreter(void)
 {
     pid_t pid = -1;
     int input = -1;
@@ -410,7 +396,8 @@ static void test_start_python_interpreter(void)
                       CPL_ERROR_NONE);
 }
 
-static void test_run_python_command(void)
+static void
+test_run_python_command(void)
 {
     close_must_produce_error = CPL_FALSE;
     read_must_produce_error = CPL_FALSE;
@@ -469,11 +456,8 @@ static void test_run_python_command(void)
     dup2_must_produce_error = CPL_FALSE;
 
     /* Mockup the python command that will just echo the input to output. */
-    mock_python(
-        "#!/bin/sh\n"
-        "cat <&"CPL_STRINGIFY(PYTHON_INPUT_FD)
-            " >&"CPL_STRINGIFY(PYTHON_OUTPUT_FD)"\n"
-    );
+    mock_python("#!/bin/sh\n"
+                "cat <&" CPL_STRINGIFY(PYTHON_INPUT_FD) " >&" CPL_STRINGIFY(PYTHON_OUTPUT_FD) "\n");
 
     /* Simulate a failure in the write() function and check error handling. */
     write_must_produce_error = CPL_TRUE;
@@ -510,7 +494,8 @@ static void test_run_python_command(void)
     close_must_produce_error = CPL_FALSE;
 }
 
-static void test_stop_python_interpreter(void)
+static void
+test_stop_python_interpreter(void)
 {
     close_must_produce_error = CPL_FALSE;
     pipe_must_produce_error = CPL_FALSE;
@@ -528,12 +513,10 @@ static void test_stop_python_interpreter(void)
     int input = dup(0);
     int output = dup(1);
     pid_t pid = fork();
-    if (pid == 0)
-    {
+    if (pid == 0) {
         exit(EXIT_SUCCESS);
     }
-    else
-    {
+    else {
         cpl_test_eq_error(stop_python_interpreter(pid, input, output),
                           CPL_ERROR_NONE);
     }
@@ -545,25 +528,24 @@ static void test_stop_python_interpreter(void)
     input = dup(0);
     output = dup(1);
     pid = fork();
-    if (pid == 0)
-    {
+    if (pid == 0) {
         sleep(10);
         exit(EXIT_FAILURE);
     }
-    else
-    {
+    else {
         cpl_test_assert(kill(pid, SIGTERM) == 0);
         cpl_test_eq_error(stop_python_interpreter(pid, input, output),
                           CPL_ERROR_FILE_IO);
     }
 }
 
-static void test_pipe_read_write(void)
+static void
+test_pipe_read_write(void)
 {
     int fildes[2];
-    const char * input = "some data";
-    char * output = NULL;
-    char * hugeinput = NULL;
+    const char *input = "some data";
+    char *output = NULL;
+    char *hugeinput = NULL;
     int hugesize = 0;
     int n = 0;
     pid_t pid = -1;
@@ -582,20 +564,19 @@ static void test_pipe_read_write(void)
     write_nbyte_limit = -1;
 
     /* Prepare a 32 MB input data buffer for some of the following tests. */
-    hugesize = 32*1024*1024;
+    hugesize = 32 * 1024 * 1024;
     hugeinput = cpl_malloc(hugesize);
-    const char * pattern = "0123456789abcdef";
-    for (n = 0; n < hugesize; ++n)
-    {
+    const char *pattern = "0123456789abcdef";
+    for (n = 0; n < hugesize; ++n) {
         hugeinput[n] = pattern[n % 16];
     }
-    hugeinput[hugesize-1] = '\0';
+    hugeinput[hugesize - 1] = '\0';
 
     /* Test that writing to a Unix pipe succeeds. */
     cpl_test_assert(pipe(fildes) == 0);
     cpl_test_eq_error(write_to_pipe(fildes[1], input, strlen(input)),
                       CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    (void)close(fildes[1]);
 
     /* Test that reading from the other end succeeds and that we get the same
        result as what was written to the pipe. */
@@ -604,7 +585,7 @@ static void test_pipe_read_write(void)
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq_string(input, output);
     free(output);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
 
     /* Test a read write cycle if we only allow one byte to be written or read
        at a time. */
@@ -613,13 +594,13 @@ static void test_pipe_read_write(void)
     cpl_test_assert(pipe(fildes) == 0);
     cpl_test_eq_error(write_to_pipe(fildes[1], input, strlen(input)),
                       CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    (void)close(fildes[1]);
     output = read_from_pipe(fildes[0]);
     cpl_test_nonnull(output);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq_string(input, output);
     free(output);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     read_nbyte_limit = -1;
     write_nbyte_limit = -1;
 
@@ -629,13 +610,13 @@ static void test_pipe_read_write(void)
     cpl_test_assert(pipe(fildes) == 0);
     cpl_test_eq_error(write_to_pipe(fildes[1], input, strlen(input)),
                       CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    (void)close(fildes[1]);
     output = read_from_pipe(fildes[0]);
     cpl_test_nonnull(output);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq_string(input, output);
     free(output);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     read_nbyte_limit = -1;
     write_nbyte_limit = -1;
 
@@ -646,7 +627,7 @@ static void test_pipe_read_write(void)
     write_call_countdown = 0;
     cpl_test_eq_error(write_to_pipe(fildes[1], input, strlen(input)),
                       CPL_ERROR_FILE_IO);
-    (void) close(fildes[1]);
+    (void)close(fildes[1]);
     write_must_produce_error = CPL_FALSE;
 
     /* Test error handling if read() fails. */
@@ -655,7 +636,7 @@ static void test_pipe_read_write(void)
     read_call_countdown = 0;
     cpl_test_null(read_from_pipe(fildes[0]));
     cpl_test_error(CPL_ERROR_FILE_IO);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     read_must_produce_error = CPL_FALSE;
 
     /* Simulate signal interruptions in write() calls and see that writing to
@@ -666,7 +647,7 @@ static void test_pipe_read_write(void)
     write_call_countdown = 2;
     cpl_test_eq_error(write_to_pipe(fildes[1], input, strlen(input)),
                       CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    (void)close(fildes[1]);
     write_must_produce_error = CPL_FALSE;
 
     /* Simulate interruptions for read() and see that read_from_pipe still
@@ -679,18 +660,18 @@ static void test_pipe_read_write(void)
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_eq_string(input, output);
     free(output);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     read_must_produce_error = CPL_FALSE;
 
     /* Test error handling in read_from_pipe if malloc() fails. */
     cpl_test_assert(pipe(fildes) == 0);
-    cpl_test_assert(write_to_pipe(fildes[1], input, strlen(input))
-                    == CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    cpl_test_assert(write_to_pipe(fildes[1], input, strlen(input)) ==
+                    CPL_ERROR_NONE);
+    (void)close(fildes[1]);
     malloc_must_produce_error = CPL_TRUE;
     cpl_test_null(read_from_pipe(fildes[0]));
     cpl_test_error(CPL_ERROR_FILE_IO);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     malloc_must_produce_error = CPL_FALSE;
 
     /* Test error handling in read_from_pipe if realloc() fails. Note that
@@ -699,33 +680,31 @@ static void test_pipe_read_write(void)
        exactly the number of bytes read, and also for huge input when it is
        called to increase the internal buffer. */
     cpl_test_assert(pipe(fildes) == 0);
-    cpl_test_assert(write_to_pipe(fildes[1], input, strlen(input))
-                    == CPL_ERROR_NONE);
-    (void) close(fildes[1]);
+    cpl_test_assert(write_to_pipe(fildes[1], input, strlen(input)) ==
+                    CPL_ERROR_NONE);
+    (void)close(fildes[1]);
     realloc_must_produce_error = CPL_TRUE;
     cpl_test_null(read_from_pipe(fildes[0]));
     cpl_test_error(CPL_ERROR_FILE_IO);
-    (void) close(fildes[0]);
+    (void)close(fildes[0]);
     realloc_must_produce_error = CPL_FALSE;
 
     cpl_test_assert(pipe(fildes) == 0);
     /* NOTE: We have to run in a separate process to avoid a deadlock, since
        something has to read from the pipe so that it does not go full. */
     pid = fork();
-    if (pid == 0)
-    {
-        (void) close(fildes[0]);
+    if (pid == 0) {
+        (void)close(fildes[0]);
         write_to_pipe(fildes[1], hugeinput, strlen(hugeinput));
-        (void) close(fildes[1]);
+        (void)close(fildes[1]);
         exit(EXIT_SUCCESS);
     }
-    else
-    {
-        (void) close(fildes[1]);
+    else {
+        (void)close(fildes[1]);
         realloc_must_produce_error = CPL_TRUE;
         cpl_test_null(read_from_pipe(fildes[0]));
         cpl_test_error(CPL_ERROR_FILE_IO);
-        (void) close(fildes[0]);
+        (void)close(fildes[0]);
         realloc_must_produce_error = CPL_FALSE;
         wait(&status);
     }
@@ -734,22 +713,20 @@ static void test_pipe_read_write(void)
        correct output. */
     cpl_test_assert(pipe(fildes) == 0);
     pid = fork();
-    if (pid == 0)
-    {
-        (void) close(fildes[0]);
+    if (pid == 0) {
+        (void)close(fildes[0]);
         write_to_pipe(fildes[1], hugeinput, strlen(hugeinput));
-        (void) close(fildes[1]);
+        (void)close(fildes[1]);
         exit(EXIT_SUCCESS);
     }
-    else
-    {
-        (void) close(fildes[1]);
+    else {
+        (void)close(fildes[1]);
         output = read_from_pipe(fildes[0]);
         cpl_test_nonnull(output);
         cpl_test_error(CPL_ERROR_NONE);
         cpl_test_eq_string(hugeinput, output);
         free(output);
-        (void) close(fildes[0]);
+        (void)close(fildes[0]);
         wait(&status);
     }
 
@@ -759,10 +736,11 @@ static void test_pipe_read_write(void)
 
 #else /* ENABLE_PYTHON_RECIPES */
 
-int main(void)
+int
+main(void)
 {
     /* Indicate to the automake test runner that the tests are skipped. */
     return 77;
 }
 
-#endif  /* ENABLE_PYTHON_RECIPES */
+#endif /* ENABLE_PYTHON_RECIPES */
